/*
 * Version.java
 *
 * Copyright (c) 2016-2018, Erik C. Thauvin (erik@thauvin.net)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 *   Neither the name of this project nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.thauvin.erik.semver;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * The <code>Version</code> class implements the annotation interface.
 *
 * @author <a href="mailto:erik@thauvin.net" target="_blank">Erik C. Thauvin</a>
 * @created 2016-01-13
 * @since 1.0
 */
@Retention(RetentionPolicy.SOURCE)
@Target(ElementType.TYPE)
public @interface Version {
    String buildMeta() default Constants.EMPTY;

    String buildMetaKey() default Constants.KEY_VERSION_BUILDMETA;

    String className() default Constants.DEFAULT_CLASS_NAME;

    int major() default Constants.DEFAULT_MAJOR;

    String majorKey() default Constants.KEY_VERSION_MAJOR;

    int minor() default Constants.DEFAULT_MINOR;

    String minorKey() default Constants.KEY_VERSION_MINOR;

    int patch() default Constants.DEFAULT_PATCH;

    String packageName() default Constants.EMPTY;

    String patchKey() default Constants.KEY_VERSION_PATCH;

    String preRelease() default Constants.EMPTY;

    String preReleaseKey() default Constants.KEY_VERSION_PRERELEASE;

    String project() default Constants.EMPTY;

    String projectKey() default Constants.KEY_VERSION_PROJECT;

    String properties() default Constants.EMPTY;

    String template() default Constants.DEFAULT_JAVA_TEMPLATE;

    String type() default Constants.DEFAULT_JAVA_TYPE;

    String keysPrefix() default Constants.DEFAULT_KEYS_PREFIX;
}